==> PackagedAuto-1.12.2-1.0.16.59-sources.jar: thelm/packagedauto/network/packet/PacketSyncEnergy.java <==
package thelm.packagedauto.network.packet;

import io.netty.buffer.ByteBuf;
import net.minecraft.client.Minecraft;
import net.minecraft.client.multiplayer.WorldClient;
import net.minecraft.tileentity.TileEntity;
import net.minecraft.util.math.BlockPos;
import net.minecraftforge.fml.common.network.NetworkRegistry.TargetPoint;
import net.minecraftforge.fml.common.network.simpleimpl.IMessage;
import net.minecraftforge.fml.common.network.simpleimpl.MessageContext;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;
import thelm.packagedauto.network.ISelfHandleMessage;
import thelm.packagedauto.network.PacketHandler;
import thelm.packagedauto.tile.TileBase;

public class PacketSyncEnergy implements ISelfHandleMessage<IMessage> {

	private long pos;
	private int energy;

	public PacketSyncEnergy() {}

	public PacketSyncEnergy(BlockPos pos, int energy) {
		this.pos = pos.func_177986_g();
		this.energy = energy;
	}

	@Override
	public void toBytes(ByteBuf buf) {
		buf.writeLong(pos);
		buf.writeInt(energy);
	}

	@Override
	public void fromBytes(ByteBuf buf) {
		pos = buf.readLong();
		energy = buf.readInt();
	}

	@SideOnly(Side.CLIENT)
	@Override
	public IMessage onMessage(MessageContext ctx) {
		Minecraft.func_71410_x().func_152344_a(()->{
			WorldClient world = Minecraft.func_71410_x().field_71441_e;
			BlockPos pos = BlockPos.func_177969_a(this.pos);
			if(world.func_175667_e(pos)) {
				TileEntity te = world.func_175625_s(pos);
				if(te instanceof TileBase) {
					((TileBase)te).getEnergyStorage().setEnergyStored(energy);
				}
			}
		});
		return null;
	}

	public static void syncEnergy(BlockPos pos, int energy, int dimension, double range) {
		PacketHandler.INSTANCE.sendToAllAround(new PacketSyncEnergy(pos, energy), new TargetPoint(dimension, pos.func_177958_n()+0.5D, pos.func_177956_o()+0.5D, pos.func_177952_p()+0.5D, range));
	}
}

==> PackagedAuto-1.12.2-1.0.23.72-sources.jar: thelm/packagedauto/network/packet/PacketSyncEnergy.java <==
package thelm.packagedauto.network.packet;

import io.netty.buffer.ByteBuf;
import net.minecraft.client.Minecraft;
import net.minecraft.client.multiplayer.WorldClient;
import net.minecraft.tileentity.TileEntity;
import net.minecraft.util.math.BlockPos;
import net.minecraftforge.fml.common.network.NetworkRegistry.TargetPoint;
import net.minecraftforge.fml.common.network.simpleimpl.IMessage;
import net.minecraftforge.fml.common.network.simpleimpl.MessageContext;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;
import thelm.packagedauto.network.ISelfHandleMessage;
import thelm.packagedauto.network.PacketHandler;
import thelm.packagedauto.tile.TileBase;

public class PacketSyncEnergy implements ISelfHandleMessage<IMessage> {

	private long pos;
	private int energy;

	public PacketSyncEnergy() {}

	public PacketSyncEnergy(BlockPos pos, int energy) {
		this.pos = pos.toLong();
		this.energy = energy;
	}

	@Override
	public void toBytes(ByteBuf buf) {
		buf.writeLong(pos);
		buf.writeInt(energy);
	}

	@Override
	public void fromBytes(ByteBuf buf) {
		pos = buf.readLong();
		energy = buf.readInt();
	}

	@SideOnly(Side.CLIENT)
	@Override
	public IMessage onMessage(MessageContext ctx) {
		Minecraft.getMinecraft().addScheduledTask(()->{
			WorldClient world = Minecraft.getMinecraft().world;
			BlockPos pos = BlockPos.fromLong(this.pos);
			if(world.isBlockLoaded(pos)) {
				TileEntity te = world.getTileEntity(pos);
				if(te instanceof TileBase) {
					((TileBase)te).getEnergyStorage().setEnergyStored(energy);
				}
			}
		});
		return null;
	}

	public static void syncEnergy(BlockPos pos, int energy, int dimension, double range) {
		PacketHandler.INSTANCE.sendToAllAround(new PacketSyncEnergy(pos, energy), new TargetPoint(dimension, pos.getX()+0.5D, pos.getY()+0.5D, pos.getZ()+0.5D, range));
	}
}
